@@ -1,11 +1,11 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * goc-group.c :  
+ * goc-group.c :
  *
  * Copyright (C) 2008-2009 Jean Brefort (jean.brefort@normalesup.org)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -26,7 +26,7 @@
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
-static GObjectClass *parent_klass;
+static GocItemClass *parent_klass;
 
 enum {
 	GROUP_PROP_0,
@@ -128,7 +128,6 @@ goc_group_draw_region (GocItem const *item, cairo_t *cr,
 		}
 		goc_item_get_bounds (item, &x, &y, &x_, &y_);
 		if (x <= x1 && x_ >= x0 && y <= y1 && y_ >= y0) {
-			cairo_set_operator (cr, goc_item_get_operator (item));
 			if (!goc_item_draw_region (item, cr, x0, y0, x1, y1))
 				goc_item_draw (item, cr);
 		}
@@ -157,7 +156,7 @@ goc_group_distance (GocItem *item, double x, double y, GocItem **near_item)
 	y -= group->y;
 	for (l = g_list_last (group->children); l; l = g_list_previous (l)) {
 		GocItem *it = GOC_ITEM (l->data);
-		if (!it->visible || it->x0 > x + th || it->x1 < x - th 
+		if (!it->visible || it->x0 > x + th || it->x1 < x - th
 		    || it->y0 > y + th || it->y1 < y - th)
 			continue;
 		dist = goc_item_distance (GOC_ITEM (l->data), x, y, &cur_item);
@@ -176,16 +175,13 @@ goc_group_realize (GocItem *item)
 {
 	GocGroup *group = GOC_GROUP (item);
 	GList *l;
-	GocItemClass *klass;
+
 	for (l = g_list_first (group->children); l; l = g_list_next (l)) {
 		GocItem *child = GOC_ITEM (l->data);
-		if (!child->realized) {
-			klass = GOC_ITEM_GET_CLASS (child);
-			if (klass->realize)
-				klass->realize (child);
-			child->realized = TRUE;
-		}
+		_goc_item_realize (child);
 	}
+
+	parent_klass->realize (item);
 }
 
 static void
@@ -193,15 +189,12 @@ goc_group_unrealize (GocItem *item)
 {
 	GocGroup *group = GOC_GROUP (item);
 	GList *l;
-	GocItemClass *klass;
+
+	parent_klass->unrealize (item);
+
 	for (l = g_list_first (group->children); l; l = g_list_next (l)) {
 		GocItem *child = GOC_ITEM (l->data);
-		if (child->realized) {
-			klass = GOC_ITEM_GET_CLASS (child);
-			if (klass->unrealize)
-				klass->unrealize (child);
-			child->realized = FALSE;
-		}
+		_goc_item_unrealize (child);
 	}
 }
 
@@ -219,18 +212,11 @@ goc_group_notify_scrolled (GocItem *item)
 }
 
 static void
-goc_group_finalize (GObject *obj)
+goc_group_dispose (GObject *obj)
 {
 	GocGroup *group = GOC_GROUP (obj);
-	GList *l = g_list_first (group->children);
-	while (l) {
-		GOC_ITEM (l->data)->parent = NULL;
-		g_object_unref (G_OBJECT (l->data));
-		l = g_list_next (l);
-	}
-	g_list_free (group->children);
-	group->children = NULL;
-	(parent_klass->finalize) (obj);
+	goc_group_clear (group);
+	((GObjectClass*)parent_klass)->dispose (obj);
 }
 
 static void
@@ -241,15 +227,15 @@ goc_group_class_init (GocItemClass *item_klass)
 
 	obj_klass->get_property = goc_group_get_property;
 	obj_klass->set_property = goc_group_set_property;
-	obj_klass->finalize = goc_group_finalize;
+	obj_klass->dispose = goc_group_dispose;
 	g_object_class_install_property (obj_klass, GROUP_PROP_X,
-		g_param_spec_double ("x", 
+		g_param_spec_double ("x",
 			_("x"),
 			_("The group horizontal offset"),
 			-G_MAXDOUBLE, G_MAXDOUBLE, 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (obj_klass, GROUP_PROP_Y,
-		g_param_spec_double ("y", 
+		g_param_spec_double ("y",
 			_("y"),
 			_("The group vertical offset"),
 			-G_MAXDOUBLE, G_MAXDOUBLE, 0.,
@@ -282,6 +268,28 @@ goc_group_new (GocGroup *parent)
 	return group;
 }
 
+void
+goc_group_clear (GocGroup *group)
+{
+	g_return_if_fail (GOC_IS_GROUP (group));
+	while (group->children != NULL) {
+		GList *this = group->children;
+		GList *next = this->next;
+		GocItem *child = this->data;
+		goc_item_destroy (child);
+		if (group->children != next) {
+			/* The most likely trigger of this is a dispose
+			   method that doesn't chain up to the parent
+			   class' dispose.  */
+			g_warning ("Trouble clearing child %p from group %p\n",
+				   child,
+				   group);
+			if (group->children == this)
+				group->children = next;
+		}
+	}
+}
+
 void
 goc_group_add_child (GocGroup *group, GocItem *item)
 {
@@ -294,6 +302,10 @@ goc_group_add_child (GocGroup *group, GocItem *item)
 	group->children = g_list_append (group->children, item);
 	item->parent = group;
 	item->canvas = group->base.canvas;
+	g_object_notify (G_OBJECT (item), "parent");
+	g_object_notify (G_OBJECT (item), "canvas");
+	if (GOC_ITEM (group)->realized)
+		_goc_item_realize (item);
 	goc_item_parent_changed (item);
 	goc_item_bounds_changed (GOC_ITEM (group));
 }
@@ -304,9 +316,15 @@ goc_group_remove_child (GocGroup *group, GocItem *item)
 	g_return_if_fail (GOC_IS_GROUP (group));
 	g_return_if_fail (GOC_IS_ITEM (item));
 	g_return_if_fail (item->parent == group);
+	if (item->canvas && item->canvas->last_item == item)
+		item->canvas->last_item = NULL;
+	if (GOC_ITEM (group)->realized)
+		_goc_item_unrealize (item);
 	group->children = g_list_remove (group->children, item);
 	item->parent = NULL;
 	item->canvas = NULL;
+	g_object_notify (G_OBJECT (item), "parent");
+	g_object_notify (G_OBJECT (item), "canvas");
 	goc_item_bounds_changed (GOC_ITEM (group));
 }
 
