@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * go-component.h :  
+ * go-component.h :
  *
  * Copyright (C) 2005 Jean Brefort (jean.brefort@normalesup.org)
  *
@@ -23,9 +23,10 @@
 #define GO_COMPONENT_H
 
 #include <glib-object.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <goffice/goffice.h>
 #include <goffice/app/goffice-app.h>
+#include <goffice/component/goffice-component.h>
 
 G_BEGIN_DECLS
 
@@ -49,7 +50,7 @@ struct _GOComponentClass {
 
 	GtkWindow* (*edit) (GOComponent *component);
 	gboolean (*get_data) (GOComponent *component, gpointer *data, int *length,
-			      void (**clearfunc) (gpointer), gpointer *user_data);
+			      GDestroyNotify *clearfunc, gpointer *user_data);
 	void (*mime_type_set) (GOComponent* component);
 	void (*set_data) (GOComponent *component);
 	void (*set_default_size) (GOComponent* component);
@@ -64,9 +65,9 @@ struct _GOComponentClass {
 
 typedef struct _GOComponentClass GOComponentClass;
 
-#define GO_COMPONENT_TYPE	(go_component_get_type ())
-#define GO_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GO_COMPONENT_TYPE, GOComponent))
-#define IS_GO_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_COMPONENT_TYPE))
+#define GO_TYPE_COMPONENT	(go_component_get_type ())
+#define GO_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_COMPONENT, GOComponent))
+#define GO_IS_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_COMPONENT))
 
 #define GOC_PARAM_PERSISTENT	(1 << (G_PARAM_USER_SHIFT+0))
 
@@ -80,7 +81,7 @@ void go_component_set_window (GOComponent *component, GdkWindow *window);
 void go_component_set_data (GOComponent *component,
 			    char const *data, int length);
 gboolean go_component_get_data (GOComponent *component, gpointer *data, int *length,
-				void (**clearfunc) (gpointer data), gpointer *user_data);
+				GDestroyNotify *clearfunc, gpointer *user_data);
 void go_component_set_size (GOComponent *component, double width, double height);
 gboolean go_component_is_resizable (GOComponent *component);
 gboolean go_component_is_editable (GOComponent *component);
