@@ -24,11 +24,12 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #include <glib/gi18n-lib.h>
@@ -80,11 +81,12 @@ gog_pie_series_element_get_property (GObject *obj, guint param_id,
 extern gpointer gog_pie_series_element_pref (GogPieSeriesElement *element, GOCmdContext *cc);
 static gpointer
 gog_pie_series_element_populate_editor (GogObject *gobj,
-					GogEditor *editor,
+					GOEditor *editor,
 					GOCmdContext *cc)
 {
 	GtkWidget *widget = gog_pie_series_element_pref (GOG_PIE_SERIES_ELEMENT (gobj), cc);
-	gog_editor_add_page (editor, widget, _("Settings"));
+	go_editor_add_page (editor, widget, _("Settings"));
+	g_object_unref (G_OBJECT (widget));
 	return widget;
 }
 #endif
@@ -96,14 +98,14 @@ gog_pie_series_element_class_init (GogPieSeriesElementClass *klass)
 
 	gobject_klass->set_property = gog_pie_series_element_set_property;
 	gobject_klass->get_property = gog_pie_series_element_get_property;
-	
+
 	ppe_parent_klass 	= g_type_class_peek_parent (klass);
 #ifdef GOFFICE_WITH_GTK
 	klass->gse_populate_editor	= gog_pie_series_element_populate_editor;
 #endif
 
 	g_object_class_install_property (gobject_klass, ELEMENT_SEPARATION,
-		g_param_spec_float ("separation", 
+		g_param_spec_float ("separation",
 			_("Separation"),
 			_("Amount a slice is extended as a percentage of the radius"),
 			0, 1000, 0.,
@@ -112,7 +114,7 @@ gog_pie_series_element_class_init (GogPieSeriesElementClass *klass)
 
 GSF_DYNAMIC_CLASS (GogPieSeriesElement, gog_pie_series_element,
 	gog_pie_series_element_class_init, NULL /*gog_pie_series_element_init*/,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
 
 /*****************************************************************************/
 
@@ -196,14 +198,16 @@ gog_pie_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 
 extern gpointer gog_pie_plot_pref (GogPiePlot *pie, GOCmdContext *cc);
 static void
-gog_pie_plot_populate_editor (GogObject *item, 
-			      GogEditor *editor,
+gog_pie_plot_populate_editor (GogObject *item,
+			      GOEditor *editor,
 			      G_GNUC_UNUSED GogDataAllocator *dalloc,
 			      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor, 
-			     gog_pie_plot_pref (GOG_PIE_PLOT (item), cc),
+	GtkWidget *widget = gog_pie_plot_pref (GOG_PIE_PLOT (item), cc);
+	go_editor_add_page (editor,
+			     widget,
 			     _("Properties"));
+	g_object_unref (G_OBJECT (widget));
 
 	(GOG_OBJECT_CLASS(pie_parent_klass)->populate_editor) (item, editor, dalloc, cc);
 }
@@ -230,25 +234,25 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 	gog_klass->view_type	= gog_pie_view_get_type ();
 
 	g_object_class_install_property (gobject_klass, PLOT_PROP_INITIAL_ANGLE,
-		g_param_spec_float ("initial-angle", 
+		g_param_spec_float ("initial-angle",
 			_("Initial angle"),
 			_("Degrees clockwise from 12 O'Clock."),
 			0, G_MAXFLOAT, 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_DEFAULT_SEPARATION,
-		g_param_spec_float ("default-separation", 
+		g_param_spec_float ("default-separation",
 			_("Default separation"),
 			_("Default amount a slice is extended as a percentage of the radius"),
 			0, G_MAXFLOAT, 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_IN_3D,
-		g_param_spec_boolean ("in-3d", 
+		g_param_spec_boolean ("in-3d",
 			_("In 3d"),
 			_("Draw 3d wedges"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_SPAN,
-		g_param_spec_float ("span", 
+		g_param_spec_float ("span",
 			_("Span"),
 			_("Total angle used as a percentage of the full circle"),
 			10., 100., 100.,
@@ -263,7 +267,7 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+		plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	}
 	plot_klass->desc.num_series_max = 1;
 	plot_klass->series_type  = gog_pie_series_get_type ();
@@ -278,14 +282,14 @@ gog_pie_plot_init (GogPiePlot *pie)
 
 GSF_DYNAMIC_CLASS (GogPiePlot, gog_pie_plot,
 	gog_pie_plot_class_init, gog_pie_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 static void
 gog_pie_plot_set_default_separation (GogPiePlot *pie, double separation)
 {
 	g_return_if_fail (GOG_PIE_PLOT (pie) != NULL);
 
-	pie->default_separation = CLAMP (separation, 0.0, 5.0); 
+	pie->default_separation = CLAMP (separation, 0.0, 5.0);
 	gog_object_emit_changed (GOG_OBJECT (pie), FALSE);
 }
 
@@ -343,13 +347,15 @@ gog_ring_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_ring_plot_pref (GogRingPlot *ring, GOCmdContext *cc);
 static void
 gog_ring_plot_populate_editor (GogObject *item,
-			       GogEditor *editor,
+			       GOEditor *editor,
 		      G_GNUC_UNUSED GogDataAllocator *dalloc,
 		      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor,
-			     gog_ring_plot_pref (GOG_RING_PLOT (item), cc),
+	GtkWidget *widget = gog_ring_plot_pref (GOG_RING_PLOT (item), cc);
+	go_editor_add_page (editor,
+			     widget,
 			     _("Properties"));
+	g_object_unref (G_OBJECT (widget));
 }
 
 static void
@@ -367,14 +373,14 @@ gog_ring_plot_class_init (GogPiePlotClass *pie_plot_klass)
 	gog_klass->populate_editor = gog_ring_plot_populate_editor;
 
 	g_object_class_install_property (gobject_klass, RING_PLOT_PROP_CENTER_SIZE,
-		g_param_spec_float ("center-size", 
+		g_param_spec_float ("center-size",
 			_("Center-size"),
 			_("Size of the center hole as a percentage of the radius"),
 			0, 100., 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	plot_klass->desc.num_series_max = G_MAXINT;
-	plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 }
 
 static void
@@ -385,7 +391,7 @@ gog_ring_plot_init (GogRingPlot *ring)
 
 GSF_DYNAMIC_CLASS (GogRingPlot, gog_ring_plot,
 	gog_ring_plot_class_init, gog_ring_plot_init,
-	GOG_PIE_PLOT_TYPE)
+	GOG_TYPE_PIE_PLOT)
 
 /*****************************************************************************/
 
@@ -397,7 +403,7 @@ typedef struct {
 } MovePieData;
 
 static gboolean
-find_element (GogView *view, double cx, double cy, double x, double y, 
+find_element (GogView *view, double cx, double cy, double x, double y,
 	      unsigned int *index, GogPieSeries **series)
 {
 	GogPiePlot *pie = GOG_PIE_PLOT (view->model);
@@ -413,12 +419,12 @@ find_element (GogView *view, double cx, double cy, double x, double y,
 	if (ptr == NULL)
 		return FALSE;
 
-	theta = (atan2 (y - cy, x - cx) 
+	theta = (atan2 (y - cy, x - cx)
 		 * 180 / M_PI - pie->initial_angle + 90.) / pie->span / 3.6;
 	if (theta < 0)
 		theta += 1.;
 
-	vals = go_data_vector_get_values (GO_DATA_VECTOR ((*series)->base.values[1].data));
+	vals = go_data_get_values ((*series)->base.values[1].data);
 	scale = 1 / (*series)->total;
 	for (*index = 0 ; *index < (*series)->base.num_elements; (*index)++) {
 		len = fabs (vals[*index]) * scale;
@@ -437,7 +443,7 @@ gog_tool_move_pie_point (GogView *view, double x, double y, GogObject **gobj)
 	GogPieSeries *series;
 	double r = view->allocation.h, cx, cy;
 	unsigned int index;
-	
+
 	if (r > view->allocation.w)
 		r = view->allocation.w;
 	r /= 2.;
@@ -446,8 +452,8 @@ gog_tool_move_pie_point (GogView *view, double x, double y, GogObject **gobj)
 
 	if (hypot (x - cx, y - cy) > fabs (r))
 		return FALSE;
-	
-	if (find_element (view, cx, cy, x, y, &index, &series)) 
+
+	if (find_element (view, cx, cy, x, y, &index, &series))
 		*gobj = GOG_OBJECT (gog_series_get_element (GOG_SERIES (series), index));
 
 	return TRUE;
@@ -496,12 +502,12 @@ gog_tool_move_pie_move (GogToolAction *action, double x, double y)
 	MovePieData *data = action->data;
 	double pos, separation;
 
-	pos = data->start_pos - 
+	pos = data->start_pos -
 		((x - action->start_x) * (data->x - action->start_x) +
-		 (y - action->start_y) * (data->y - action->start_y)) / 
-		data->start_distance; 
+		 (y - action->start_y) * (data->y - action->start_y)) /
+		data->start_distance;
 	separation = (pos - 0.5 * data->r) / (data->r - pos);
-					     
+
 	gog_pie_plot_set_default_separation (pie, separation);
 }
 
@@ -513,11 +519,11 @@ gog_tool_move_pie_double_click (GogToolAction *action)
 	GogObject *obj;
 	unsigned int index;
 
-	if (!find_element (action->view, data->x, data->y, 
+	if (!find_element (action->view, data->x, data->y,
 			   action->start_x, action->start_y,
 			   &index, &series))
 		return;
-	
+
 	obj = GOG_OBJECT (gog_series_get_element (GOG_SERIES (series), index));
 	if (obj == NULL) {
 		obj = g_object_new (gog_pie_series_element_get_type (),
@@ -529,10 +535,10 @@ gog_tool_move_pie_double_click (GogToolAction *action)
 static GogTool gog_tool_move_pie = {
 	N_("Move pie"),
 	GDK_FLEUR,
-	gog_tool_move_pie_point, 
+	gog_tool_move_pie_point,
 	gog_tool_move_pie_render,
-	gog_tool_move_pie_init, 
-	gog_tool_move_pie_move, 
+	gog_tool_move_pie_init,
+	gog_tool_move_pie_move,
 	gog_tool_move_pie_double_click,
 	NULL /*destroy*/
 };
@@ -557,7 +563,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 	unsigned elem, k;
 	GOPath *path;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (model));
-	GogStyle *style;
+	GOStyle *style;
 	GSList *ptr;
 	unsigned num_series = 0;
 	unsigned index;
@@ -583,17 +589,17 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	separation_max = .0;
 	outline_width_max = .0;
-	if ((style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series))))
-		outline_width_max = gog_renderer_line_size (view->renderer, style->outline.width);
+	if ((style = go_styled_object_get_style (GO_STYLED_OBJECT (series))))
+		outline_width_max = gog_renderer_line_size (view->renderer, style->line.width);
 	for (overrides = gog_series_get_overrides (GOG_SERIES (series));
 	     overrides != NULL;
 	     overrides = overrides->next) {
 		separation = GOG_PIE_SERIES_ELEMENT (overrides->data)->separation;
 		if (separation_max < separation)
 			separation_max = separation;
-		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (overrides->data));
-		if (outline_width_max < style->outline.width)
-			outline_width_max = style->outline.width;
+		style = go_styled_object_get_style (GO_STYLED_OBJECT (overrides->data));
+		if (outline_width_max < style->line.width)
+			outline_width_max = style->line.width;
 	}
 	if (separation_max < -model->default_separation)
 		separation_max = -model->default_separation;
@@ -684,7 +690,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 		/* centre things */
 		cx = view->allocation.x + view->allocation.w/2.;
 		cy = view->allocation.y + view->allocation.h/2.;
-	
+
 		r_tot = view->allocation.h;
 		if (r_tot > view->allocation.w)
 			r_tot = view->allocation.w;
@@ -706,10 +712,10 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 			continue;
 		if (index > num_series) /* people snuck extra series into a pie */
 			break;
-		
-		if (num_series == index) 
+
+		if (num_series == index)
 			r -= outline_width_max / 2.0;
-		
+
 		has_hole = center_radius > 0. || index > 1;
 		r_int = center_radius + r * ((double)index - 1.0) / (double)num_series;
 		r_ext = center_radius + r * (double)index / (double)num_series;
@@ -717,11 +723,11 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 		theta = (model->initial_angle + series->initial_angle) * M_PI / 180. - M_PI / 2.;
 
 		scale = 2 * M_PI / 100 * model->span / series->total;
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
 
 		style = GOG_STYLED_OBJECT (series)->style;
 		if (model->base.vary_style_by_element)
-			style = gog_style_dup (style);
+			style = go_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
 		overrides = gog_series_get_overrides (GOG_SERIES (series));
@@ -740,11 +746,11 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 				gpse = GOG_PIE_SERIES_ELEMENT (overrides->data);
 				overrides = overrides->next;
 				gog_renderer_push_style (view->renderer,
-					gog_styled_object_get_style (
-						GOG_STYLED_OBJECT (gpse)));
+					go_styled_object_get_style (
+						GO_STYLED_OBJECT (gpse)));
 			} else if (model->base.vary_style_by_element)
 				gog_theme_fillin_style (theme, style, GOG_OBJECT (series),
-							model->base.index_num + k, FALSE);
+							model->base.index_num + k, GO_STYLE_FILL);
 
 			/* only separate the outer ring */
 			separated_cx = cx;
@@ -787,7 +793,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 static void
 gog_pie_view_build_toolkit (GogView *view)
 {
-	(GOG_VIEW_CLASS (pie_view_parent_klass)->build_toolkit) (view);	
+	(GOG_VIEW_CLASS (pie_view_parent_klass)->build_toolkit) (view);
 #ifdef GOFFICE_WITH_GTK
 	view->toolkit = g_slist_prepend (view->toolkit, &gog_tool_move_pie);
 #endif
@@ -804,7 +810,7 @@ gog_pie_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogPieView, gog_pie_view,
 	gog_pie_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
@@ -864,9 +870,8 @@ gog_pie_series_update (GogObject *obj)
 	unsigned old_num = series->base.num_elements;
 
 	if (series->base.values[1].data != NULL) {
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
-		len = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
+		len = go_data_get_vector_size (series->base.values[1].data);
 	}
 	series->base.num_elements = len;
 
@@ -892,19 +897,19 @@ gog_pie_series_class_init (GObjectClass *gobject_klass)
 
 	series_parent_klass = g_type_class_peek_parent (gobject_klass);
 	gog_klass->update = gog_pie_series_update;
-	series_klass->series_element_type = GOG_PIE_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_PIE_SERIES_ELEMENT;
 
 	gobject_klass->set_property = gog_pie_series_set_property;
 	gobject_klass->get_property = gog_pie_series_get_property;
 
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INITIAL_ANGLE,
-		g_param_spec_float ("initial-angle", 
+		g_param_spec_float ("initial-angle",
 			_("Initial-angle"),
 			_("Degrees clockwise from 12 O'Clock"),
 			0, G_MAXFLOAT, 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_SEPARATION,
-		g_param_spec_float ("separation", 
+		g_param_spec_float ("separation",
 			_("Separation"),
 			_("Default amount a slice is extended as a percentage of the radius"),
 			0, G_MAXFLOAT, 0.,
@@ -913,7 +918,7 @@ gog_pie_series_class_init (GObjectClass *gobject_klass)
 
 GSF_DYNAMIC_CLASS (GogPieSeries, gog_pie_series,
 	   gog_pie_series_class_init, NULL,
-	   GOG_SERIES_TYPE)
+	   GOG_TYPE_SERIES)
 
 G_MODULE_EXPORT void
 go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
