@@ -40,24 +40,38 @@ typedef GogRTPlot GogRadarPlot;
 
 typedef GogRTPlot GogPolarPlot;
 
-#define GOG_RT_PLOT_TYPE	(gog_rt_plot_get_type ())
-#define GOG_RT_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_RT_PLOT_TYPE, GogRTPlot))
-#define GOG_IS_PLOT_RT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_RT_PLOT_TYPE))
+typedef struct {
+	GogPolarPlot	base;
+	struct {
+		double minima, maxima;
+	} z;
+	gboolean	hide_outliers;
+} GogColorPolarPlot;
+
+#define GOG_TYPE_RT_PLOT	(gog_rt_plot_get_type ())
+#define GOG_RT_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_RT_PLOT, GogRTPlot))
+#define GOG_IS_PLOT_RT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_RT_PLOT))
 
 GType gog_rt_plot_get_type (void);
 
-#define GOG_RADAR_PLOT_TYPE	(gog_radar_plot_get_type ())
-#define GOG_RADAR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_RADAR_PLOT_TYPE, GogRadarPlot))
-#define GOG_IS_PLOT_RADAR(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_RADAR_PLOT_TYPE))
+#define GOG_TYPE_RADAR_PLOT	(gog_radar_plot_get_type ())
+#define GOG_RADAR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_RADAR_PLOT, GogRadarPlot))
+#define GOG_IS_PLOT_RADAR(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_RADAR_PLOT))
 
 GType gog_radar_plot_get_type (void);
 
-#define GOG_POLAR_PLOT_TYPE	(gog_polar_plot_get_type ())
-#define GOG_POLAR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_POLAR_PLOT_TYPE, GogPolarPlot))
-#define GOG_IS_PLOT_POLAR(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_POLAR_PLOT_TYPE))
+#define GOG_TYPE_POLAR_PLOT	(gog_polar_plot_get_type ())
+#define GOG_POLAR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_POLAR_PLOT, GogPolarPlot))
+#define GOG_IS_PLOT_POLAR(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_POLAR_PLOT))
 
 GType gog_polar_plot_get_type (void);
 
+#define GOG_TYPE_COLOR_POLAR_PLOT	(gog_color_polar_plot_get_type ())
+#define GOG_COLOR_POLAR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_COLOR_POLAR_PLOT, GogColorPolarPlot))
+#define GOG_IS_PLOT_COLOR_POLAR(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_COLOR_POLAR_PLOT))
+
+GType gog_color_polar_plot_get_type (void);
+
 G_END_DECLS
 
 #endif /* GOG_RADAR_H */
