@@ -33,6 +33,7 @@ typedef struct {
 	struct {
 		double minima, maxima;
 		GOFormat *fmt;
+		GODateConventions const *date_conv;
 	} x, y;
 } Gog2DPlot;
 
@@ -40,6 +41,7 @@ typedef struct {
 	Gog2DPlot	base;
 	gboolean	default_style_has_markers;
 	gboolean	default_style_has_lines;
+	gboolean	default_style_has_fill;
 	gboolean	use_splines;			/* for compatibility with goffice 0.2.x */
 } GogXYPlot;
 
@@ -54,10 +56,12 @@ typedef struct {
 typedef struct {
 	Gog2DPlot	base;
 	gboolean	default_style_has_lines;
+	gboolean	default_style_has_fill;
 	gboolean	hide_outliers;
 	struct {
 		double minima, maxima;
 		GOFormat *fmt;
+		GODateConventions const *date_conv;
 	} z;
 } GogXYColorPlot;
 
@@ -67,34 +71,38 @@ typedef struct {
 
 GType gog_2d_plot_get_type (void);
 
-#define GOG_XY_PLOT_TYPE	(gog_xy_plot_get_type ())
-#define GOG_XY_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_PLOT_TYPE, GogXYPlot))
-#define GOG_IS_XY_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_PLOT_TYPE))
+#define GOG_TYPE_XY_PLOT	(gog_xy_plot_get_type ())
+#define GOG_XY_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_PLOT, GogXYPlot))
+#define GOG_IS_XY_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_PLOT))
 
 GType gog_xy_plot_get_type (void);
 
-#define GOG_BUBBLE_PLOT_TYPE	(gog_bubble_plot_get_type ())
-#define GOG_BUBBLE_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_BUBBLE_PLOT_TYPE, GogBubblePlot))
-#define GOG_IS_BUBBLE_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_BUBBLE_PLOT_TYPE))
+#define GOG_TYPE_BUBBLE_PLOT	(gog_bubble_plot_get_type ())
+#define GOG_BUBBLE_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_BUBBLE_PLOT, GogBubblePlot))
+#define GOG_IS_BUBBLE_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_BUBBLE_PLOT))
 
 GType gog_bubble_plot_get_type (void);
 
-#define GOG_XY_COLOR_PLOT_TYPE	(gog_xy_color_plot_get_type ())
-#define GOG_XY_COLOR_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_COLOR_PLOT_TYPE, GogXYColorPlot))
-#define GOG_IS_XY_COLOR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_COLOR_PLOT_TYPE))
+#define GOG_TYPE_XY_COLOR_PLOT	(gog_xy_color_plot_get_type ())
+#define GOG_XY_COLOR_PLOT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_COLOR_PLOT, GogXYColorPlot))
+#define GOG_IS_XY_COLOR_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_COLOR_PLOT))
 
 GType gog_xy_color_plot_get_type (void);
 
 typedef struct {
-	GogSeries base;
-	GogErrorBar *x_errors, *y_errors;
-	GogObject *hdroplines, *vdroplines;
-	gboolean invalid_as_zero;
+	GogSeries 	   base;
+	GogErrorBar 	  *x_errors;
+	GogErrorBar 	  *y_errors;
+	GogObject 	  *hdroplines;
+    GogObject	  *vdroplines;
+	gboolean 	   invalid_as_zero;
+	double		   clamped_derivs[2]; /* start and and slopes for clamped cubic splines */
+	GogDataset	  *interpolation_props;
 } GogXYSeries;
 
-#define GOG_XY_SERIES_TYPE	(gog_xy_series_get_type ())
-#define GOG_XY_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_SERIES_TYPE, GogXYSeries))
-#define GOG_IS_XY_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_SERIES_TYPE))
+#define GOG_TYPE_XY_SERIES	(gog_xy_series_get_type ())
+#define GOG_XY_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_SERIES, GogXYSeries))
+#define GOG_IS_XY_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_SERIES))
 
 G_END_DECLS
 
